@@ -60,6 +60,12 @@ webkit_cookie_persistent_storage_get_type (void);
 WEBKIT_API GType
 webkit_cookie_accept_policy_get_type (void);
 
+/* Enumerations from WebKitEditorState.h. */
+#define WEBKIT_TYPE_EDITOR_TYPING_ATTRIBUTES webkit_editor_typing_attributes_get_type ()
+
+WEBKIT_API GType
+webkit_editor_typing_attributes_get_type (void);
+
 /* Enumerations from WebKitError.h. */
 #define WEBKIT_TYPE_NETWORK_ERROR webkit_network_error_get_type ()
 
@@ -132,6 +138,12 @@ webkit_print_operation_response_get_type (void);
 WEBKIT_API GType
 webkit_script_dialog_type_get_type (void);
 
+/* Enumerations from WebKitSettings.h. */
+#define WEBKIT_TYPE_HARDWARE_ACCELERATION_POLICY webkit_hardware_acceleration_policy_get_type ()
+
+WEBKIT_API GType
+webkit_hardware_acceleration_policy_get_type (void);
+
 /* Enumerations from WebKitUserContent.h. */
 #define WEBKIT_TYPE_USER_CONTENT_INJECTED_FRAMES webkit_user_content_injected_frames_get_type ()
 
@@ -164,6 +176,11 @@ webkit_process_model_get_type (void);
 WEBKIT_API GType
 webkit_tls_errors_policy_get_type (void);
 
+#define WEBKIT_TYPE_NETWORK_PROXY_MODE webkit_network_proxy_mode_get_type ()
+
+WEBKIT_API GType
+webkit_network_proxy_mode_get_type (void);
+
 /* Enumerations from WebKitWebView.h. */
 #define WEBKIT_TYPE_POLICY_DECISION_TYPE webkit_policy_decision_type_get_type ()
 
@@ -195,6 +212,12 @@ webkit_snapshot_options_get_type (void);
 WEBKIT_API GType
 webkit_snapshot_region_get_type (void);
 
+/* Enumerations from WebKitWebsiteData.h. */
+#define WEBKIT_TYPE_WEBSITE_DATA_TYPES webkit_website_data_types_get_type ()
+
+WEBKIT_API GType
+webkit_website_data_types_get_type (void);
+
 G_END_DECLS
 
 #endif
